require File.expand_path(File.dirname(__FILE__) + '/../spec_config.rb')

describe Account do

  before do
    @user = Account.new email: 'test@domain.com', password: 'password', password_confirmation: 'password', role: 'admin'
    @user.save
  end

  after do
    @user.destroy
  end

  it 'should instantiate a Mongo document' do
    @user.must be_document
  end

  it 'finds account by id compatible with call from AuthenticationHelper' do
    [Account.find_by_id(@user.id), Account.find(@user.id)].must_equal [@user, @user]
  end

  it 'verifies that the account has a given password' do
    @user.has_password?('password').must_equal true
  end

  it 'verifies that the account does not have a given password' do
    @user.has_password?('bad_password').must_equal false
  end

  it 'authenticates a user based on email and password combination' do
    Account.authenticate('test@domain.com', 'password').must_equal @user
  end

  it 'does not authenticate a user if email and password combination are invalid' do
    Account.authenticate('test@domain.com', 'bad_password').must_equal nil
  end

end
